@@ -1,18 +1,29 @@
-# $ podman run -v $HOME/opencpn-gpg:/root/.gnupg --platform linux/amd64 \
-#     -v=$PWD:/build -v=/tmp/pkg-amd64:/output -e DOCKER_BUILD=1 \
-#      -ti debian:bookworm-backports
-# # /build/build.sh
-#
-# $ podman run -v $HOME/opencpn-gpg:/root/.gnupg --platform linux/aarch64 \
-#     -v=$PWD:/build -v=/tmp/pkg-aarch64:/output -e DOCKER_BUILD=1 \
-#     -ti debian:bookworm-backports
-# # /build/build.sh
+#!/bin/bash
+if [[ "$1" == "-h" || "$1" == "--help" ]]; then
+ cat << "EOF"
+
+# Initial run:
+test -d /tmp/pkg-amd64 || mkdir /tmp/pkg-amd64
+podman run -v $HOME/opencpn-gpg:/root/.gnupg --platform linux/amd64 \
+     -v=$PWD:/build -v=/tmp/pkg-amd64:/output -e DOCKER_BUILD=1 \
+     --name debian_13-amd64 -ti debian:trixie-backports /bin/bash
+
+# Subsequent runs:
+podman start debian_13-amd64
+podman cp ~/.devscripts debian_13-amd64:/root
+podman exec -ti debian_13-amd64 /bin/bash
+# /build/build.sh
+
+EOF
+  exit 0
+fi
 
 # Install build tools
 apt update --allow-unauthenticated 
 apt install -y devscripts equivs git-buildpackage
 
 # Clone opencpn
+cd /build
 mkdir opencpn
 cd opencpn/
 git clone -b debian/bookworm-backports https://github.com/opencpn/opencpn.git
@@ -31,4 +42,4 @@ gbp buildpackage --git-upstream-tag=upstream/5.9.1-beta1+dfsg
 
 # Copy out results to /output
 cd ..
-cp *.deb /output
+cp *.deb *.buildinfo *.build *.changes *.dsc /output
